@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import wsgi
 
 
 class Cfg(object):
@@ -22,6 +21,10 @@ class Cfg(object):
     ROUTING_QUEUE = ['pysi.auto_routing']  # очередь функций роутинга
     JINJA2_EXTENSIONS = ['jinja2.ext.with_']
 
+    STATIC_PATH = 'static'
+    STATIC_URL_PREFIX  = '/static/'
+    STATIC_VERSION_CACHING = True  # кэшировать посчитанные версионные хеши
+
     def set_defaults(self, **kwargs):
         '''
         Добавляем дефолтные атрибуты
